/* remote.c */

#include "config.h"

#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <getopt.h>
#include <glib.h>

#include "logger.h"
#include "socket.h"

#ifndef RCNAME_S
#define RCNAME_S "mcplay-remote"
#endif
#ifndef RCVERS_S
#define RCVERS_S "0.1"
#endif

static gint rcport = DEF_PORT;
static SocketData *socket = NULL;

void print_help(void)
{
   g_print(RCNAME_S", version "RCVERS_S"\n"
           "Copyright (C) 2002 Tobias Rapp (yahuxo@gmx.de).\n"
           "\n"
           "Usage: "RCNAME_S" [options] commands...\n"
           "\n"
           "Options are (defaults in brackets):\n");
   g_print("  -P, --port        Use this port for remote control connection.  [%d]\n", DEF_PORT);
   g_print("  -s, --server      Connect to this server.  [127.0.0.1]\n"
           "  -h, --help        Shows this text.\n"
           "\n"
           "For command syntax see documentation\n");
}

int main(int argc, char *argv[])
{
   struct option long_options[] =
   {
      { "port",       1, NULL, 'P' },
      { "server",     1, NULL, 's' },
      { "help",       0, NULL, 'h' },
      { 0, 0, 0, 0 }
   };
   gchar *hostname;
   gchar cmd[INPUT_MAX];
   gchar c;
   gint i;
   
   hostname = g_strdup("127.0.0.1");
   
   while( (c=getopt_long(argc, argv, "P:s:h", long_options, NULL)) != EOF )
   {
      switch(c)
      {
         case 'P':
            rcport = (gint)g_strtod(optarg, NULL);
            break;
         case 's':
            g_free(hostname);
            hostname = g_strdup(optarg);
            break;
         case 'h':
            print_help();
            exit(0);
            break;
         default:
            g_print("Unknown charakter '%c'\n", c);
         case '?':
            g_print("Try '"RCNAME_S" --help' for more information.\n");
            exit(-1);
      }
   }
   
   if( optind > argc-1 )
   {  g_print("Missing some arguments:\n\n");
      print_help();
      exit(-1);
   }
   
   /* g_print("cpy '%s'\n", argv[optind]); */
   strcpy(cmd, argv[optind]);
   for(i=optind+1; i<argc; i++)
   {
      /* g_print("cat '%s'\n", argv[i]); */
      strcat(cmd, " ");
      strcat(cmd, argv[i]);
   }
   
   socket = socket_new_client(hostname, rcport);
   socket_write(socket, cmd, strlen(cmd)+1);
   socket_free(socket);
   
   return 0;
}
